Documentation
¶
Index ¶
Constants ¶
const ( // ChildOf means a span is the child of another span ChildOf ReferenceType = "CHILD_OF" // FollowsFrom means a span follows from another span FollowsFrom ReferenceType = "FOLLOWS_FROM" // StringType indicates a string value stored in KeyValue StringType ValueType = "string" // BoolType indicates a Boolean value stored in KeyValue BoolType ValueType = "bool" // Int64Type indicates a 64bit signed integer value stored in KeyValue Int64Type ValueType = "int64" // Float64Type indicates a 64bit float value stored in KeyValue Float64Type ValueType = "float64" // BinaryType indicates an arbitrary byte array stored in KeyValue BinaryType ValueType = "binary" )
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type KeyValue ¶
type KeyValue struct {
Key string `json:"key"`
Type ValueType `json:"type,omitempty"`
Value interface{} `json:"value"`
}
KeyValue is a key-value pair with typed value.
type Process ¶
type Process struct {
ServiceName string `json:"serviceName"`
Tags []KeyValue `json:"tags"`
// Alternative representation of tags for better kibana support
Tag map[string]interface{} `json:"tag,omitempty"`
}
Process is the process emitting a set of spans
type Reference ¶
type Reference struct {
RefType ReferenceType `json:"refType"`
TraceID TraceID `json:"traceID"`
SpanID SpanID `json:"spanID"`
}
Reference is a reference from one span to another
type ReferenceType ¶
type ReferenceType string
ReferenceType is the reference type of one span to another
Click to show internal directories.
Click to hide internal directories.